==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPinColumnCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDetailDescription } from "./WebPinColumnCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPinColumnCancellableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, _super);
    function WebPinColumnCancellableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a == null) {
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebPinColumnCancellableEventArgsDetail", function () { return new WebPinColumnCancellableEventArgsDetailDescription(); });
        a.ac("WebPinColumnCancellableEventArgsDetail", WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, 'WebPinColumnCancellableEventArgsDetailDescriptionMetadata');
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPinColumnCancellableEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPinColumnCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDetailDescription } from "./WebPinColumnCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPinColumnCancellableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, _super);
    function WebPinColumnCancellableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a == null) {
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("InsertAtIndex", "Number:double");
        a.item("IsPinned", "Boolean");
        a.item("Cancel", "Boolean");
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebPinColumnCancellableEventArgsDetail", function () { return new WebPinColumnCancellableEventArgsDetailDescription(); });
        a.ad("WebPinColumnCancellableEventArgsDetail", WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, 'WebPinColumnCancellableEventArgsDetailDescriptionMetadata');
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPinColumnCancellableEventArgsDetailDescriptionMetadata };
